===========================================
 Gnocchi -- Resource metering as a Service
===========================================

The Gnocchi project procdes a REST interface to catalog and measure resources.

.. toctree::
   :glob:

   basic
   install
   devstack
   rest
   statsd
   resource_types

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
